CtsConfig

Enum CtsConfig 

pub enum CtsConfig {
    Enabled,
    Disabled,
}
Available on crate feature unstable only.
Configuration for CTS (Clear To Send) flow control.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Enabled

Enable CTS flow control (TX).



Disabled

Disable CTS flow control (TX).