HwFlowControl

Struct HwFlowControl 

pub struct HwFlowControl {
    pub cts: CtsConfig,
    pub rts: RtsConfig,
}
Available on crate feature unstable only.
Hardware flow control configuration.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Fields

cts: CtsConfig

CTS configuration.

rts: RtsConfig

RTS configuration.